==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/PasswordPolicyRecoveryEmailProperties.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PasswordPolicyRecoveryEmailRecoveryToken;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordPolicyRecoveryEmailProperties
 */
@JsonPropertyOrder({ PasswordPolicyRecoveryEmailProperties.JSON_PROPERTY_RECOVERY_TOKEN })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PasswordPolicyRecoveryEmailProperties implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_RECOVERY_TOKEN = "recoveryToken";
    private PasswordPolicyRecoveryEmailRecoveryToken recoveryToken;

    public PasswordPolicyRecoveryEmailProperties() {
    }

    public PasswordPolicyRecoveryEmailProperties recoveryToken(PasswordPolicyRecoveryEmailRecoveryToken recoveryToken) {

        this.recoveryToken = recoveryToken;
        return this;
    }

    /**
     * Get recoveryToken
     *
     * @return recoveryToken
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_RECOVERY_TOKEN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyRecoveryEmailRecoveryToken getRecoveryToken() {
        return recoveryToken;
    }

    @JsonProperty(JSON_PROPERTY_RECOVERY_TOKEN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRecoveryToken(PasswordPolicyRecoveryEmailRecoveryToken recoveryToken) {
        this.recoveryToken = recoveryToken;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordPolicyRecoveryEmailProperties passwordPolicyRecoveryEmailProperties = (PasswordPolicyRecoveryEmailProperties) o;
        return Objects.equals(this.recoveryToken, passwordPolicyRecoveryEmailProperties.recoveryToken);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(recoveryToken);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordPolicyRecoveryEmailProperties {\n");
        sb.append("    recoveryToken: ").append(toIndentedString(recoveryToken)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/PasswordPolicyRecoveryEmailProperties.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PasswordPolicyRecoveryEmailRecoveryToken;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PasswordPolicyRecoveryEmailProperties
 */
@JsonPropertyOrder({ PasswordPolicyRecoveryEmailProperties.JSON_PROPERTY_RECOVERY_TOKEN })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class PasswordPolicyRecoveryEmailProperties implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_RECOVERY_TOKEN = "recoveryToken";
    private PasswordPolicyRecoveryEmailRecoveryToken recoveryToken;

    public PasswordPolicyRecoveryEmailProperties() {
    }

    public PasswordPolicyRecoveryEmailProperties recoveryToken(PasswordPolicyRecoveryEmailRecoveryToken recoveryToken) {

        this.recoveryToken = recoveryToken;
        return this;
    }

    /**
     * Get recoveryToken
     *
     * @return recoveryToken
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_RECOVERY_TOKEN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PasswordPolicyRecoveryEmailRecoveryToken getRecoveryToken() {
        return recoveryToken;
    }

    @JsonProperty(JSON_PROPERTY_RECOVERY_TOKEN)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRecoveryToken(PasswordPolicyRecoveryEmailRecoveryToken recoveryToken) {
        this.recoveryToken = recoveryToken;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PasswordPolicyRecoveryEmailProperties passwordPolicyRecoveryEmailProperties = (PasswordPolicyRecoveryEmailProperties) o;
        return Objects.equals(this.recoveryToken, passwordPolicyRecoveryEmailProperties.recoveryToken);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(recoveryToken);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PasswordPolicyRecoveryEmailProperties {\n");
        sb.append("    recoveryToken: ").append(toIndentedString(recoveryToken)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
